# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KeypairArgs', 'Keypair']

@pulumi.input_type
class KeypairArgs:
    def __init__(__self__, *,
                 key_pair_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['KeypairTagArgs']]]] = None):
        """
        The set of arguments for constructing a Keypair resource.
        :param pulumi.Input[builtins.str] key_pair_name: 密钥对名称。不可与已有名称重复。长度限制在 2～64 个字符之间。允许使用点号“.”分隔字符成多段，每段允许使用大小写字母、数字或连字符“-”。不能以“-”和“.”开头或结尾，不能连续使用“-”或者“.”。
        :param pulumi.Input[builtins.str] description: 密钥对的描述，默认值为空字符串。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”长度限制在255个字符以内。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 操作的实例ID。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] public_key: 密钥对的公钥信息。
        """
        pulumi.set(__self__, "key_pair_name", key_pair_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_ids is not None:
            pulumi.set(__self__, "instance_ids", instance_ids)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if public_key is not None:
            pulumi.set(__self__, "public_key", public_key)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> pulumi.Input[builtins.str]:
        """
        密钥对名称。不可与已有名称重复。长度限制在 2～64 个字符之间。允许使用点号“.”分隔字符成多段，每段允许使用大小写字母、数字或连字符“-”。不能以“-”和“.”开头或结尾，不能连续使用“-”或者“.”。
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥对的描述，默认值为空字符串。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        操作的实例ID。
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源所属项目，一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥对的公钥信息。
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_key", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KeypairTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KeypairTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _KeypairState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 finger_print: Optional[pulumi.Input[builtins.str]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 key_pair_id: Optional[pulumi.Input[builtins.str]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['KeypairTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Keypair resources.
        :param pulumi.Input[builtins.str] created_time: 密钥对创建时间。
        :param pulumi.Input[builtins.str] description: 密钥对的描述，默认值为空字符串。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] finger_print: 密钥对的指纹。根据RFC4716定义的公钥指纹格式，采用MD5信息摘要算法。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 操作的实例ID。
        :param pulumi.Input[builtins.str] key_pair_id: 密钥对唯一ID。
        :param pulumi.Input[builtins.str] key_pair_name: 密钥对名称。不可与已有名称重复。长度限制在 2～64 个字符之间。允许使用点号“.”分隔字符成多段，每段允许使用大小写字母、数字或连字符“-”。不能以“-”和“.”开头或结尾，不能连续使用“-”或者“.”。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] public_key: 密钥对的公钥信息。
        :param pulumi.Input[builtins.str] updated_time: 密钥对更新时间。
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if finger_print is not None:
            pulumi.set(__self__, "finger_print", finger_print)
        if instance_ids is not None:
            pulumi.set(__self__, "instance_ids", instance_ids)
        if key_pair_id is not None:
            pulumi.set(__self__, "key_pair_id", key_pair_id)
        if key_pair_name is not None:
            pulumi.set(__self__, "key_pair_name", key_pair_name)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if public_key is not None:
            pulumi.set(__self__, "public_key", public_key)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥对创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥对的描述，默认值为空字符串。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="fingerPrint")
    def finger_print(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥对的指纹。根据RFC4716定义的公钥指纹格式，采用MD5信息摘要算法。
        """
        return pulumi.get(self, "finger_print")

    @finger_print.setter
    def finger_print(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "finger_print", value)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        操作的实例ID。
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter(name="keyPairId")
    def key_pair_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥对唯一ID。
        """
        return pulumi.get(self, "key_pair_id")

    @key_pair_id.setter
    def key_pair_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key_pair_id", value)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥对名称。不可与已有名称重复。长度限制在 2～64 个字符之间。允许使用点号“.”分隔字符成多段，每段允许使用大小写字母、数字或连字符“-”。不能以“-”和“.”开头或结尾，不能连续使用“-”或者“.”。
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源所属项目，一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥对的公钥信息。
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_key", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['KeypairTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['KeypairTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        密钥对更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:ecs/keypair:Keypair")
class Keypair(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KeypairTagArgs', 'KeypairTagArgsDict']]]]] = None,
                 __props__=None):
        """
        ECS 密钥对（Keypair）默认采用 RSA 2048 位加密算法生成一对关联密钥，包含公钥（public key）和私钥（private key）。其中，公钥用于对数据进行加密处理，可将明文转换为不可直接读取的密文；私钥则作为解密的唯一凭证，能将密文还原为原始明文，实现安全的身份验证与数据传输。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        e_cs_keypair_demo = bytepluscc.ecs.Keypair("ECSKeypairDemo",
            key_pair_name="ECSKeypairDemo",
            project_name="default",
            description="ECSKeypairDemo Description",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/keypair:Keypair example "key_pair_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 密钥对的描述，默认值为空字符串。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”长度限制在255个字符以内。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 操作的实例ID。
        :param pulumi.Input[builtins.str] key_pair_name: 密钥对名称。不可与已有名称重复。长度限制在 2～64 个字符之间。允许使用点号“.”分隔字符成多段，每段允许使用大小写字母、数字或连字符“-”。不能以“-”和“.”开头或结尾，不能连续使用“-”或者“.”。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] public_key: 密钥对的公钥信息。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KeypairArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ECS 密钥对（Keypair）默认采用 RSA 2048 位加密算法生成一对关联密钥，包含公钥（public key）和私钥（private key）。其中，公钥用于对数据进行加密处理，可将明文转换为不可直接读取的密文；私钥则作为解密的唯一凭证，能将密文还原为原始明文，实现安全的身份验证与数据传输。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        e_cs_keypair_demo = bytepluscc.ecs.Keypair("ECSKeypairDemo",
            key_pair_name="ECSKeypairDemo",
            project_name="default",
            description="ECSKeypairDemo Description",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/keypair:Keypair example "key_pair_name"
        ```

        :param str resource_name: The name of the resource.
        :param KeypairArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KeypairArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KeypairTagArgs', 'KeypairTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KeypairArgs.__new__(KeypairArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["instance_ids"] = instance_ids
            if key_pair_name is None and not opts.urn:
                raise TypeError("Missing required property 'key_pair_name'")
            __props__.__dict__["key_pair_name"] = key_pair_name
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["public_key"] = public_key
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_time"] = None
            __props__.__dict__["finger_print"] = None
            __props__.__dict__["key_pair_id"] = None
            __props__.__dict__["updated_time"] = None
        super(Keypair, __self__).__init__(
            'bytepluscc:ecs/keypair:Keypair',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            finger_print: Optional[pulumi.Input[builtins.str]] = None,
            instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            key_pair_id: Optional[pulumi.Input[builtins.str]] = None,
            key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            public_key: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['KeypairTagArgs', 'KeypairTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Keypair':
        """
        Get an existing Keypair resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 密钥对创建时间。
        :param pulumi.Input[builtins.str] description: 密钥对的描述，默认值为空字符串。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”长度限制在255个字符以内。
        :param pulumi.Input[builtins.str] finger_print: 密钥对的指纹。根据RFC4716定义的公钥指纹格式，采用MD5信息摘要算法。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 操作的实例ID。
        :param pulumi.Input[builtins.str] key_pair_id: 密钥对唯一ID。
        :param pulumi.Input[builtins.str] key_pair_name: 密钥对名称。不可与已有名称重复。长度限制在 2～64 个字符之间。允许使用点号“.”分隔字符成多段，每段允许使用大小写字母、数字或连字符“-”。不能以“-”和“.”开头或结尾，不能连续使用“-”或者“.”。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        :param pulumi.Input[builtins.str] public_key: 密钥对的公钥信息。
        :param pulumi.Input[builtins.str] updated_time: 密钥对更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KeypairState.__new__(_KeypairState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["finger_print"] = finger_print
        __props__.__dict__["instance_ids"] = instance_ids
        __props__.__dict__["key_pair_id"] = key_pair_id
        __props__.__dict__["key_pair_name"] = key_pair_name
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["public_key"] = public_key
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        return Keypair(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        密钥对创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        密钥对的描述，默认值为空字符串。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fingerPrint")
    def finger_print(self) -> pulumi.Output[builtins.str]:
        """
        密钥对的指纹。根据RFC4716定义的公钥指纹格式，采用MD5信息摘要算法。
        """
        return pulumi.get(self, "finger_print")

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        操作的实例ID。
        """
        return pulumi.get(self, "instance_ids")

    @property
    @pulumi.getter(name="keyPairId")
    def key_pair_id(self) -> pulumi.Output[builtins.str]:
        """
        密钥对唯一ID。
        """
        return pulumi.get(self, "key_pair_id")

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> pulumi.Output[builtins.str]:
        """
        密钥对名称。不可与已有名称重复。长度限制在 2～64 个字符之间。允许使用点号“.”分隔字符成多段，每段允许使用大小写字母、数字或连字符“-”。不能以“-”和“.”开头或结尾，不能连续使用“-”或者“.”。
        """
        return pulumi.get(self, "key_pair_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        资源所属项目，一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> pulumi.Output[builtins.str]:
        """
        密钥对的公钥信息。
        """
        return pulumi.get(self, "public_key")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.KeypairTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        密钥对更新时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InvocationArgs', 'Invocation']

@pulumi.input_type
class InvocationArgs:
    def __init__(__self__, *,
                 command_id: pulumi.Input[builtins.str],
                 instance_ids: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 invocation_name: pulumi.Input[builtins.str],
                 frequency: Optional[pulumi.Input[builtins.str]] = None,
                 invocation_description: Optional[pulumi.Input[builtins.str]] = None,
                 launch_time: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 recurrence_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 repeat_mode: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InvocationTagArgs']]]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 windows_password: Optional[pulumi.Input[builtins.str]] = None,
                 working_dir: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Invocation resource.
        :param pulumi.Input[builtins.str] command_id: 命令ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 实例ID列表，最多支持200个ID。
        :param pulumi.Input[builtins.str] invocation_name: 作业名称。不超过64个字符。暂不限制特殊字符。同地域下作业名称可重复。
        :param pulumi.Input[builtins.str] frequency: 执行频率。RepeatMode=Rate 时本参数必填。格式：<执行间隔数值><执行间隔单位>，执行间隔单位：支持分钟（5m-60m）、小时（1h-24h）和天（1d-7d）。执行间隔基于固定频率，与作业实际执行需要的时间无关。创建作业后基于LaunchTime执行一次，根据间隔设置确定下一次执行时间。
        :param pulumi.Input[builtins.str] invocation_description: 作业描述，默认为空字符串，不超过256个字符。
        :param pulumi.Input[builtins.str] launch_time: 执行时间。
        :param pulumi.Input[builtins.str] parameters: 命令中包含自定义参数时，需通过本参数传入自定义参数的键值对。自定义参数个数范围为0~60。Key不允许为空字符串，最多支持64个字符。Value允许为空字符串。自定义参数与原始命令内容在Base64编码后，综合长度不能超过16KB。设置的自定义参数名集合必须为创建命令时定义的参数集的子集。对于未传入的参数，使用默认值代替。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。
        :param pulumi.Input[builtins.str] recurrence_end_time: 周期结束时间，仅适用于周期任务（Rate）。
        :param pulumi.Input[builtins.str] repeat_mode: 设置命令执行的方式。Once：默认，表示立即执行命令。Rate：周期执行命令，需要通过Frequency参数传入Rate表达式指定执行周期。Fixed：定时执行命令，需要通过LaunchTime参数指定的执行时间。
        :param pulumi.Input[builtins.int] timeout: 创建的命令在ECS实例中执行时最大的超时时间，单位为秒。默认值：60。可选范围为：30~86400。
        :param pulumi.Input[builtins.str] username: 在ECS实例中执行命令的用户名称。
        :param pulumi.Input[builtins.str] windows_password: 自定义windows用户的密码。
        :param pulumi.Input[builtins.str] working_dir: 创建的命令在ECS实例中运行的目录。
        """
        pulumi.set(__self__, "command_id", command_id)
        pulumi.set(__self__, "instance_ids", instance_ids)
        pulumi.set(__self__, "invocation_name", invocation_name)
        if frequency is not None:
            pulumi.set(__self__, "frequency", frequency)
        if invocation_description is not None:
            pulumi.set(__self__, "invocation_description", invocation_description)
        if launch_time is not None:
            pulumi.set(__self__, "launch_time", launch_time)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if recurrence_end_time is not None:
            pulumi.set(__self__, "recurrence_end_time", recurrence_end_time)
        if repeat_mode is not None:
            pulumi.set(__self__, "repeat_mode", repeat_mode)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if windows_password is not None:
            pulumi.set(__self__, "windows_password", windows_password)
        if working_dir is not None:
            pulumi.set(__self__, "working_dir", working_dir)

    @property
    @pulumi.getter(name="commandId")
    def command_id(self) -> pulumi.Input[builtins.str]:
        """
        命令ID。
        """
        return pulumi.get(self, "command_id")

    @command_id.setter
    def command_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "command_id", value)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        实例ID列表，最多支持200个ID。
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter(name="invocationName")
    def invocation_name(self) -> pulumi.Input[builtins.str]:
        """
        作业名称。不超过64个字符。暂不限制特殊字符。同地域下作业名称可重复。
        """
        return pulumi.get(self, "invocation_name")

    @invocation_name.setter
    def invocation_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "invocation_name", value)

    @property
    @pulumi.getter
    def frequency(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        执行频率。RepeatMode=Rate 时本参数必填。格式：<执行间隔数值><执行间隔单位>，执行间隔单位：支持分钟（5m-60m）、小时（1h-24h）和天（1d-7d）。执行间隔基于固定频率，与作业实际执行需要的时间无关。创建作业后基于LaunchTime执行一次，根据间隔设置确定下一次执行时间。
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter(name="invocationDescription")
    def invocation_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        作业描述，默认为空字符串，不超过256个字符。
        """
        return pulumi.get(self, "invocation_description")

    @invocation_description.setter
    def invocation_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "invocation_description", value)

    @property
    @pulumi.getter(name="launchTime")
    def launch_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        执行时间。
        """
        return pulumi.get(self, "launch_time")

    @launch_time.setter
    def launch_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_time", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令中包含自定义参数时，需通过本参数传入自定义参数的键值对。自定义参数个数范围为0~60。Key不允许为空字符串，最多支持64个字符。Value允许为空字符串。自定义参数与原始命令内容在Base64编码后，综合长度不能超过16KB。设置的自定义参数名集合必须为创建命令时定义的参数集的子集。对于未传入的参数，使用默认值代替。
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源所属项目，一个资源只能归属于一个项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="recurrenceEndTime")
    def recurrence_end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        周期结束时间，仅适用于周期任务（Rate）。
        """
        return pulumi.get(self, "recurrence_end_time")

    @recurrence_end_time.setter
    def recurrence_end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "recurrence_end_time", value)

    @property
    @pulumi.getter(name="repeatMode")
    def repeat_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        设置命令执行的方式。Once：默认，表示立即执行命令。Rate：周期执行命令，需要通过Frequency参数传入Rate表达式指定执行周期。Fixed：定时执行命令，需要通过LaunchTime参数指定的执行时间。
        """
        return pulumi.get(self, "repeat_mode")

    @repeat_mode.setter
    def repeat_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "repeat_mode", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InvocationTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InvocationTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        创建的命令在ECS实例中执行时最大的超时时间，单位为秒。默认值：60。可选范围为：30~86400。
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "timeout", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        在ECS实例中执行命令的用户名称。
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="windowsPassword")
    def windows_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定义windows用户的密码。
        """
        return pulumi.get(self, "windows_password")

    @windows_password.setter
    def windows_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "windows_password", value)

    @property
    @pulumi.getter(name="workingDir")
    def working_dir(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建的命令在ECS实例中运行的目录。
        """
        return pulumi.get(self, "working_dir")

    @working_dir.setter
    def working_dir(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "working_dir", value)


@pulumi.input_type
class _InvocationState:
    def __init__(__self__, *,
                 command_content: Optional[pulumi.Input[builtins.str]] = None,
                 command_description: Optional[pulumi.Input[builtins.str]] = None,
                 command_id: Optional[pulumi.Input[builtins.str]] = None,
                 command_name: Optional[pulumi.Input[builtins.str]] = None,
                 command_provider: Optional[pulumi.Input[builtins.str]] = None,
                 command_type: Optional[pulumi.Input[builtins.str]] = None,
                 enable_parameter: Optional[pulumi.Input[builtins.bool]] = None,
                 end_time: Optional[pulumi.Input[builtins.str]] = None,
                 frequency: Optional[pulumi.Input[builtins.str]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 instance_number: Optional[pulumi.Input[builtins.int]] = None,
                 invocation_description: Optional[pulumi.Input[builtins.str]] = None,
                 invocation_id: Optional[pulumi.Input[builtins.str]] = None,
                 invocation_name: Optional[pulumi.Input[builtins.str]] = None,
                 invocation_results: Optional[pulumi.Input[Sequence[pulumi.Input['InvocationInvocationResultArgs']]]] = None,
                 invocation_status: Optional[pulumi.Input[builtins.str]] = None,
                 launch_time: Optional[pulumi.Input[builtins.str]] = None,
                 parameter_definitions: Optional[pulumi.Input[Sequence[pulumi.Input['InvocationParameterDefinitionArgs']]]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 recurrence_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 repeat_mode: Optional[pulumi.Input[builtins.str]] = None,
                 start_time: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['InvocationTagArgs']]]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 windows_password: Optional[pulumi.Input[builtins.str]] = None,
                 working_dir: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Invocation resources.
        :param pulumi.Input[builtins.str] command_content: 命令内容。
        :param pulumi.Input[builtins.str] command_description: 被调用命令的描述。
        :param pulumi.Input[builtins.str] command_id: 命令ID。
        :param pulumi.Input[builtins.str] command_name: 任务触发时的命令名称。
        :param pulumi.Input[builtins.str] command_provider: 被调用命令的提供方。
        :param pulumi.Input[builtins.str] command_type: 作业触发的命令类型。
        :param pulumi.Input[builtins.bool] enable_parameter: 被调用命令是否使用自定义参数。true：已启用。false：未启用。
        :param pulumi.Input[builtins.str] end_time: 任务结束时间。
        :param pulumi.Input[builtins.str] frequency: 执行频率。RepeatMode=Rate 时本参数必填。格式：<执行间隔数值><执行间隔单位>，执行间隔单位：支持分钟（5m-60m）、小时（1h-24h）和天（1d-7d）。执行间隔基于固定频率，与作业实际执行需要的时间无关。创建作业后基于LaunchTime执行一次，根据间隔设置确定下一次执行时间。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 实例ID列表，最多支持200个ID。
        :param pulumi.Input[builtins.int] instance_number: 执行实例数量。
        :param pulumi.Input[builtins.str] invocation_description: 作业描述，默认为空字符串，不超过256个字符。
        :param pulumi.Input[builtins.str] invocation_id: 任务执行 ID。
        :param pulumi.Input[builtins.str] invocation_name: 作业名称。不超过64个字符。暂不限制特殊字符。同地域下作业名称可重复。
        :param pulumi.Input[builtins.str] invocation_status: 命令执行的总执行状态。
        :param pulumi.Input[builtins.str] launch_time: 执行时间。
        :param pulumi.Input[builtins.str] parameters: 命令中包含自定义参数时，需通过本参数传入自定义参数的键值对。自定义参数个数范围为0~60。Key不允许为空字符串，最多支持64个字符。Value允许为空字符串。自定义参数与原始命令内容在Base64编码后，综合长度不能超过16KB。设置的自定义参数名集合必须为创建命令时定义的参数集的子集。对于未传入的参数，使用默认值代替。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。
        :param pulumi.Input[builtins.str] recurrence_end_time: 周期结束时间，仅适用于周期任务（Rate）。
        :param pulumi.Input[builtins.str] repeat_mode: 设置命令执行的方式。Once：默认，表示立即执行命令。Rate：周期执行命令，需要通过Frequency参数传入Rate表达式指定执行周期。Fixed：定时执行命令，需要通过LaunchTime参数指定的执行时间。
        :param pulumi.Input[builtins.str] start_time: 任务开始时间。
        :param pulumi.Input[builtins.int] timeout: 创建的命令在ECS实例中执行时最大的超时时间，单位为秒。默认值：60。可选范围为：30~86400。
        :param pulumi.Input[builtins.str] username: 在ECS实例中执行命令的用户名称。
        :param pulumi.Input[builtins.str] windows_password: 自定义windows用户的密码。
        :param pulumi.Input[builtins.str] working_dir: 创建的命令在ECS实例中运行的目录。
        """
        if command_content is not None:
            pulumi.set(__self__, "command_content", command_content)
        if command_description is not None:
            pulumi.set(__self__, "command_description", command_description)
        if command_id is not None:
            pulumi.set(__self__, "command_id", command_id)
        if command_name is not None:
            pulumi.set(__self__, "command_name", command_name)
        if command_provider is not None:
            pulumi.set(__self__, "command_provider", command_provider)
        if command_type is not None:
            pulumi.set(__self__, "command_type", command_type)
        if enable_parameter is not None:
            pulumi.set(__self__, "enable_parameter", enable_parameter)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if frequency is not None:
            pulumi.set(__self__, "frequency", frequency)
        if instance_ids is not None:
            pulumi.set(__self__, "instance_ids", instance_ids)
        if instance_number is not None:
            pulumi.set(__self__, "instance_number", instance_number)
        if invocation_description is not None:
            pulumi.set(__self__, "invocation_description", invocation_description)
        if invocation_id is not None:
            pulumi.set(__self__, "invocation_id", invocation_id)
        if invocation_name is not None:
            pulumi.set(__self__, "invocation_name", invocation_name)
        if invocation_results is not None:
            pulumi.set(__self__, "invocation_results", invocation_results)
        if invocation_status is not None:
            pulumi.set(__self__, "invocation_status", invocation_status)
        if launch_time is not None:
            pulumi.set(__self__, "launch_time", launch_time)
        if parameter_definitions is not None:
            pulumi.set(__self__, "parameter_definitions", parameter_definitions)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if recurrence_end_time is not None:
            pulumi.set(__self__, "recurrence_end_time", recurrence_end_time)
        if repeat_mode is not None:
            pulumi.set(__self__, "repeat_mode", repeat_mode)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if windows_password is not None:
            pulumi.set(__self__, "windows_password", windows_password)
        if working_dir is not None:
            pulumi.set(__self__, "working_dir", working_dir)

    @property
    @pulumi.getter(name="commandContent")
    def command_content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令内容。
        """
        return pulumi.get(self, "command_content")

    @command_content.setter
    def command_content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "command_content", value)

    @property
    @pulumi.getter(name="commandDescription")
    def command_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        被调用命令的描述。
        """
        return pulumi.get(self, "command_description")

    @command_description.setter
    def command_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "command_description", value)

    @property
    @pulumi.getter(name="commandId")
    def command_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令ID。
        """
        return pulumi.get(self, "command_id")

    @command_id.setter
    def command_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "command_id", value)

    @property
    @pulumi.getter(name="commandName")
    def command_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        任务触发时的命令名称。
        """
        return pulumi.get(self, "command_name")

    @command_name.setter
    def command_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "command_name", value)

    @property
    @pulumi.getter(name="commandProvider")
    def command_provider(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        被调用命令的提供方。
        """
        return pulumi.get(self, "command_provider")

    @command_provider.setter
    def command_provider(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "command_provider", value)

    @property
    @pulumi.getter(name="commandType")
    def command_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        作业触发的命令类型。
        """
        return pulumi.get(self, "command_type")

    @command_type.setter
    def command_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "command_type", value)

    @property
    @pulumi.getter(name="enableParameter")
    def enable_parameter(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        被调用命令是否使用自定义参数。true：已启用。false：未启用。
        """
        return pulumi.get(self, "enable_parameter")

    @enable_parameter.setter
    def enable_parameter(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_parameter", value)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        任务结束时间。
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter
    def frequency(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        执行频率。RepeatMode=Rate 时本参数必填。格式：<执行间隔数值><执行间隔单位>，执行间隔单位：支持分钟（5m-60m）、小时（1h-24h）和天（1d-7d）。执行间隔基于固定频率，与作业实际执行需要的时间无关。创建作业后基于LaunchTime执行一次，根据间隔设置确定下一次执行时间。
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "frequency", value)

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        实例ID列表，最多支持200个ID。
        """
        return pulumi.get(self, "instance_ids")

    @instance_ids.setter
    def instance_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "instance_ids", value)

    @property
    @pulumi.getter(name="instanceNumber")
    def instance_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        执行实例数量。
        """
        return pulumi.get(self, "instance_number")

    @instance_number.setter
    def instance_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "instance_number", value)

    @property
    @pulumi.getter(name="invocationDescription")
    def invocation_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        作业描述，默认为空字符串，不超过256个字符。
        """
        return pulumi.get(self, "invocation_description")

    @invocation_description.setter
    def invocation_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "invocation_description", value)

    @property
    @pulumi.getter(name="invocationId")
    def invocation_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        任务执行 ID。
        """
        return pulumi.get(self, "invocation_id")

    @invocation_id.setter
    def invocation_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "invocation_id", value)

    @property
    @pulumi.getter(name="invocationName")
    def invocation_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        作业名称。不超过64个字符。暂不限制特殊字符。同地域下作业名称可重复。
        """
        return pulumi.get(self, "invocation_name")

    @invocation_name.setter
    def invocation_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "invocation_name", value)

    @property
    @pulumi.getter(name="invocationResults")
    def invocation_results(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InvocationInvocationResultArgs']]]]:
        return pulumi.get(self, "invocation_results")

    @invocation_results.setter
    def invocation_results(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InvocationInvocationResultArgs']]]]):
        pulumi.set(self, "invocation_results", value)

    @property
    @pulumi.getter(name="invocationStatus")
    def invocation_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令执行的总执行状态。
        """
        return pulumi.get(self, "invocation_status")

    @invocation_status.setter
    def invocation_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "invocation_status", value)

    @property
    @pulumi.getter(name="launchTime")
    def launch_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        执行时间。
        """
        return pulumi.get(self, "launch_time")

    @launch_time.setter
    def launch_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "launch_time", value)

    @property
    @pulumi.getter(name="parameterDefinitions")
    def parameter_definitions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InvocationParameterDefinitionArgs']]]]:
        return pulumi.get(self, "parameter_definitions")

    @parameter_definitions.setter
    def parameter_definitions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InvocationParameterDefinitionArgs']]]]):
        pulumi.set(self, "parameter_definitions", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令中包含自定义参数时，需通过本参数传入自定义参数的键值对。自定义参数个数范围为0~60。Key不允许为空字符串，最多支持64个字符。Value允许为空字符串。自定义参数与原始命令内容在Base64编码后，综合长度不能超过16KB。设置的自定义参数名集合必须为创建命令时定义的参数集的子集。对于未传入的参数，使用默认值代替。
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源所属项目，一个资源只能归属于一个项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="recurrenceEndTime")
    def recurrence_end_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        周期结束时间，仅适用于周期任务（Rate）。
        """
        return pulumi.get(self, "recurrence_end_time")

    @recurrence_end_time.setter
    def recurrence_end_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "recurrence_end_time", value)

    @property
    @pulumi.getter(name="repeatMode")
    def repeat_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        设置命令执行的方式。Once：默认，表示立即执行命令。Rate：周期执行命令，需要通过Frequency参数传入Rate表达式指定执行周期。Fixed：定时执行命令，需要通过LaunchTime参数指定的执行时间。
        """
        return pulumi.get(self, "repeat_mode")

    @repeat_mode.setter
    def repeat_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "repeat_mode", value)

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        任务开始时间。
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_time", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InvocationTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InvocationTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        创建的命令在ECS实例中执行时最大的超时时间，单位为秒。默认值：60。可选范围为：30~86400。
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "timeout", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        在ECS实例中执行命令的用户名称。
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="windowsPassword")
    def windows_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定义windows用户的密码。
        """
        return pulumi.get(self, "windows_password")

    @windows_password.setter
    def windows_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "windows_password", value)

    @property
    @pulumi.getter(name="workingDir")
    def working_dir(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建的命令在ECS实例中运行的目录。
        """
        return pulumi.get(self, "working_dir")

    @working_dir.setter
    def working_dir(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "working_dir", value)


@pulumi.type_token("bytepluscc:ecs/invocation:Invocation")
class Invocation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 command_id: Optional[pulumi.Input[builtins.str]] = None,
                 frequency: Optional[pulumi.Input[builtins.str]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 invocation_description: Optional[pulumi.Input[builtins.str]] = None,
                 invocation_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_time: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 recurrence_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 repeat_mode: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InvocationTagArgs', 'InvocationTagArgsDict']]]]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 windows_password: Optional[pulumi.Input[builtins.str]] = None,
                 working_dir: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        云助手是火山引擎打造的原生自动化运维工具。您可以创建立即执行、周期执行、定时执行的作业任务，创建完成后完，云助手客户端将按照执行模式自动开始执行。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        invocation_demo = bytepluscc.ecs.Invocation("InvocationDemo",
            invocation_name="InvocationDemo",
            invocation_description="InvocationDemo desc",
            working_dir="/home",
            username="InvocationDemo",
            windows_password="********",
            timeout=60,
            instance_ids=["i-ye2v6l0pvkqc6inxxxxx"],
            repeat_mode="Rate",
            frequency="1h",
            launch_time="2025-08-30T11:10Z",
            recurrence_end_time="2025-08-31T11:04Z",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            command_id="cmd-ye28kugp249tzrexxxxx",
            parameters="{\\"dirname\\":\\"10\\"}")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/invocation:Invocation example "invocation_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] command_id: 命令ID。
        :param pulumi.Input[builtins.str] frequency: 执行频率。RepeatMode=Rate 时本参数必填。格式：<执行间隔数值><执行间隔单位>，执行间隔单位：支持分钟（5m-60m）、小时（1h-24h）和天（1d-7d）。执行间隔基于固定频率，与作业实际执行需要的时间无关。创建作业后基于LaunchTime执行一次，根据间隔设置确定下一次执行时间。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 实例ID列表，最多支持200个ID。
        :param pulumi.Input[builtins.str] invocation_description: 作业描述，默认为空字符串，不超过256个字符。
        :param pulumi.Input[builtins.str] invocation_name: 作业名称。不超过64个字符。暂不限制特殊字符。同地域下作业名称可重复。
        :param pulumi.Input[builtins.str] launch_time: 执行时间。
        :param pulumi.Input[builtins.str] parameters: 命令中包含自定义参数时，需通过本参数传入自定义参数的键值对。自定义参数个数范围为0~60。Key不允许为空字符串，最多支持64个字符。Value允许为空字符串。自定义参数与原始命令内容在Base64编码后，综合长度不能超过16KB。设置的自定义参数名集合必须为创建命令时定义的参数集的子集。对于未传入的参数，使用默认值代替。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。
        :param pulumi.Input[builtins.str] recurrence_end_time: 周期结束时间，仅适用于周期任务（Rate）。
        :param pulumi.Input[builtins.str] repeat_mode: 设置命令执行的方式。Once：默认，表示立即执行命令。Rate：周期执行命令，需要通过Frequency参数传入Rate表达式指定执行周期。Fixed：定时执行命令，需要通过LaunchTime参数指定的执行时间。
        :param pulumi.Input[builtins.int] timeout: 创建的命令在ECS实例中执行时最大的超时时间，单位为秒。默认值：60。可选范围为：30~86400。
        :param pulumi.Input[builtins.str] username: 在ECS实例中执行命令的用户名称。
        :param pulumi.Input[builtins.str] windows_password: 自定义windows用户的密码。
        :param pulumi.Input[builtins.str] working_dir: 创建的命令在ECS实例中运行的目录。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InvocationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        云助手是火山引擎打造的原生自动化运维工具。您可以创建立即执行、周期执行、定时执行的作业任务，创建完成后完，云助手客户端将按照执行模式自动开始执行。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        invocation_demo = bytepluscc.ecs.Invocation("InvocationDemo",
            invocation_name="InvocationDemo",
            invocation_description="InvocationDemo desc",
            working_dir="/home",
            username="InvocationDemo",
            windows_password="********",
            timeout=60,
            instance_ids=["i-ye2v6l0pvkqc6inxxxxx"],
            repeat_mode="Rate",
            frequency="1h",
            launch_time="2025-08-30T11:10Z",
            recurrence_end_time="2025-08-31T11:04Z",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            command_id="cmd-ye28kugp249tzrexxxxx",
            parameters="{\\"dirname\\":\\"10\\"}")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/invocation:Invocation example "invocation_id"
        ```

        :param str resource_name: The name of the resource.
        :param InvocationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InvocationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 command_id: Optional[pulumi.Input[builtins.str]] = None,
                 frequency: Optional[pulumi.Input[builtins.str]] = None,
                 instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 invocation_description: Optional[pulumi.Input[builtins.str]] = None,
                 invocation_name: Optional[pulumi.Input[builtins.str]] = None,
                 launch_time: Optional[pulumi.Input[builtins.str]] = None,
                 parameters: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 recurrence_end_time: Optional[pulumi.Input[builtins.str]] = None,
                 repeat_mode: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InvocationTagArgs', 'InvocationTagArgsDict']]]]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 windows_password: Optional[pulumi.Input[builtins.str]] = None,
                 working_dir: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InvocationArgs.__new__(InvocationArgs)

            if command_id is None and not opts.urn:
                raise TypeError("Missing required property 'command_id'")
            __props__.__dict__["command_id"] = command_id
            __props__.__dict__["frequency"] = frequency
            if instance_ids is None and not opts.urn:
                raise TypeError("Missing required property 'instance_ids'")
            __props__.__dict__["instance_ids"] = instance_ids
            __props__.__dict__["invocation_description"] = invocation_description
            if invocation_name is None and not opts.urn:
                raise TypeError("Missing required property 'invocation_name'")
            __props__.__dict__["invocation_name"] = invocation_name
            __props__.__dict__["launch_time"] = launch_time
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["recurrence_end_time"] = recurrence_end_time
            __props__.__dict__["repeat_mode"] = repeat_mode
            __props__.__dict__["tags"] = tags
            __props__.__dict__["timeout"] = timeout
            __props__.__dict__["username"] = username
            __props__.__dict__["windows_password"] = windows_password
            __props__.__dict__["working_dir"] = working_dir
            __props__.__dict__["command_content"] = None
            __props__.__dict__["command_description"] = None
            __props__.__dict__["command_name"] = None
            __props__.__dict__["command_provider"] = None
            __props__.__dict__["command_type"] = None
            __props__.__dict__["enable_parameter"] = None
            __props__.__dict__["end_time"] = None
            __props__.__dict__["instance_number"] = None
            __props__.__dict__["invocation_id"] = None
            __props__.__dict__["invocation_results"] = None
            __props__.__dict__["invocation_status"] = None
            __props__.__dict__["parameter_definitions"] = None
            __props__.__dict__["start_time"] = None
        super(Invocation, __self__).__init__(
            'bytepluscc:ecs/invocation:Invocation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            command_content: Optional[pulumi.Input[builtins.str]] = None,
            command_description: Optional[pulumi.Input[builtins.str]] = None,
            command_id: Optional[pulumi.Input[builtins.str]] = None,
            command_name: Optional[pulumi.Input[builtins.str]] = None,
            command_provider: Optional[pulumi.Input[builtins.str]] = None,
            command_type: Optional[pulumi.Input[builtins.str]] = None,
            enable_parameter: Optional[pulumi.Input[builtins.bool]] = None,
            end_time: Optional[pulumi.Input[builtins.str]] = None,
            frequency: Optional[pulumi.Input[builtins.str]] = None,
            instance_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            instance_number: Optional[pulumi.Input[builtins.int]] = None,
            invocation_description: Optional[pulumi.Input[builtins.str]] = None,
            invocation_id: Optional[pulumi.Input[builtins.str]] = None,
            invocation_name: Optional[pulumi.Input[builtins.str]] = None,
            invocation_results: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InvocationInvocationResultArgs', 'InvocationInvocationResultArgsDict']]]]] = None,
            invocation_status: Optional[pulumi.Input[builtins.str]] = None,
            launch_time: Optional[pulumi.Input[builtins.str]] = None,
            parameter_definitions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InvocationParameterDefinitionArgs', 'InvocationParameterDefinitionArgsDict']]]]] = None,
            parameters: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            recurrence_end_time: Optional[pulumi.Input[builtins.str]] = None,
            repeat_mode: Optional[pulumi.Input[builtins.str]] = None,
            start_time: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InvocationTagArgs', 'InvocationTagArgsDict']]]]] = None,
            timeout: Optional[pulumi.Input[builtins.int]] = None,
            username: Optional[pulumi.Input[builtins.str]] = None,
            windows_password: Optional[pulumi.Input[builtins.str]] = None,
            working_dir: Optional[pulumi.Input[builtins.str]] = None) -> 'Invocation':
        """
        Get an existing Invocation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] command_content: 命令内容。
        :param pulumi.Input[builtins.str] command_description: 被调用命令的描述。
        :param pulumi.Input[builtins.str] command_id: 命令ID。
        :param pulumi.Input[builtins.str] command_name: 任务触发时的命令名称。
        :param pulumi.Input[builtins.str] command_provider: 被调用命令的提供方。
        :param pulumi.Input[builtins.str] command_type: 作业触发的命令类型。
        :param pulumi.Input[builtins.bool] enable_parameter: 被调用命令是否使用自定义参数。true：已启用。false：未启用。
        :param pulumi.Input[builtins.str] end_time: 任务结束时间。
        :param pulumi.Input[builtins.str] frequency: 执行频率。RepeatMode=Rate 时本参数必填。格式：<执行间隔数值><执行间隔单位>，执行间隔单位：支持分钟（5m-60m）、小时（1h-24h）和天（1d-7d）。执行间隔基于固定频率，与作业实际执行需要的时间无关。创建作业后基于LaunchTime执行一次，根据间隔设置确定下一次执行时间。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] instance_ids: 实例ID列表，最多支持200个ID。
        :param pulumi.Input[builtins.int] instance_number: 执行实例数量。
        :param pulumi.Input[builtins.str] invocation_description: 作业描述，默认为空字符串，不超过256个字符。
        :param pulumi.Input[builtins.str] invocation_id: 任务执行 ID。
        :param pulumi.Input[builtins.str] invocation_name: 作业名称。不超过64个字符。暂不限制特殊字符。同地域下作业名称可重复。
        :param pulumi.Input[builtins.str] invocation_status: 命令执行的总执行状态。
        :param pulumi.Input[builtins.str] launch_time: 执行时间。
        :param pulumi.Input[builtins.str] parameters: 命令中包含自定义参数时，需通过本参数传入自定义参数的键值对。自定义参数个数范围为0~60。Key不允许为空字符串，最多支持64个字符。Value允许为空字符串。自定义参数与原始命令内容在Base64编码后，综合长度不能超过16KB。设置的自定义参数名集合必须为创建命令时定义的参数集的子集。对于未传入的参数，使用默认值代替。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。
        :param pulumi.Input[builtins.str] recurrence_end_time: 周期结束时间，仅适用于周期任务（Rate）。
        :param pulumi.Input[builtins.str] repeat_mode: 设置命令执行的方式。Once：默认，表示立即执行命令。Rate：周期执行命令，需要通过Frequency参数传入Rate表达式指定执行周期。Fixed：定时执行命令，需要通过LaunchTime参数指定的执行时间。
        :param pulumi.Input[builtins.str] start_time: 任务开始时间。
        :param pulumi.Input[builtins.int] timeout: 创建的命令在ECS实例中执行时最大的超时时间，单位为秒。默认值：60。可选范围为：30~86400。
        :param pulumi.Input[builtins.str] username: 在ECS实例中执行命令的用户名称。
        :param pulumi.Input[builtins.str] windows_password: 自定义windows用户的密码。
        :param pulumi.Input[builtins.str] working_dir: 创建的命令在ECS实例中运行的目录。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InvocationState.__new__(_InvocationState)

        __props__.__dict__["command_content"] = command_content
        __props__.__dict__["command_description"] = command_description
        __props__.__dict__["command_id"] = command_id
        __props__.__dict__["command_name"] = command_name
        __props__.__dict__["command_provider"] = command_provider
        __props__.__dict__["command_type"] = command_type
        __props__.__dict__["enable_parameter"] = enable_parameter
        __props__.__dict__["end_time"] = end_time
        __props__.__dict__["frequency"] = frequency
        __props__.__dict__["instance_ids"] = instance_ids
        __props__.__dict__["instance_number"] = instance_number
        __props__.__dict__["invocation_description"] = invocation_description
        __props__.__dict__["invocation_id"] = invocation_id
        __props__.__dict__["invocation_name"] = invocation_name
        __props__.__dict__["invocation_results"] = invocation_results
        __props__.__dict__["invocation_status"] = invocation_status
        __props__.__dict__["launch_time"] = launch_time
        __props__.__dict__["parameter_definitions"] = parameter_definitions
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["recurrence_end_time"] = recurrence_end_time
        __props__.__dict__["repeat_mode"] = repeat_mode
        __props__.__dict__["start_time"] = start_time
        __props__.__dict__["tags"] = tags
        __props__.__dict__["timeout"] = timeout
        __props__.__dict__["username"] = username
        __props__.__dict__["windows_password"] = windows_password
        __props__.__dict__["working_dir"] = working_dir
        return Invocation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="commandContent")
    def command_content(self) -> pulumi.Output[builtins.str]:
        """
        命令内容。
        """
        return pulumi.get(self, "command_content")

    @property
    @pulumi.getter(name="commandDescription")
    def command_description(self) -> pulumi.Output[builtins.str]:
        """
        被调用命令的描述。
        """
        return pulumi.get(self, "command_description")

    @property
    @pulumi.getter(name="commandId")
    def command_id(self) -> pulumi.Output[builtins.str]:
        """
        命令ID。
        """
        return pulumi.get(self, "command_id")

    @property
    @pulumi.getter(name="commandName")
    def command_name(self) -> pulumi.Output[builtins.str]:
        """
        任务触发时的命令名称。
        """
        return pulumi.get(self, "command_name")

    @property
    @pulumi.getter(name="commandProvider")
    def command_provider(self) -> pulumi.Output[builtins.str]:
        """
        被调用命令的提供方。
        """
        return pulumi.get(self, "command_provider")

    @property
    @pulumi.getter(name="commandType")
    def command_type(self) -> pulumi.Output[builtins.str]:
        """
        作业触发的命令类型。
        """
        return pulumi.get(self, "command_type")

    @property
    @pulumi.getter(name="enableParameter")
    def enable_parameter(self) -> pulumi.Output[builtins.bool]:
        """
        被调用命令是否使用自定义参数。true：已启用。false：未启用。
        """
        return pulumi.get(self, "enable_parameter")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Output[builtins.str]:
        """
        任务结束时间。
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter
    def frequency(self) -> pulumi.Output[builtins.str]:
        """
        执行频率。RepeatMode=Rate 时本参数必填。格式：<执行间隔数值><执行间隔单位>，执行间隔单位：支持分钟（5m-60m）、小时（1h-24h）和天（1d-7d）。执行间隔基于固定频率，与作业实际执行需要的时间无关。创建作业后基于LaunchTime执行一次，根据间隔设置确定下一次执行时间。
        """
        return pulumi.get(self, "frequency")

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        实例ID列表，最多支持200个ID。
        """
        return pulumi.get(self, "instance_ids")

    @property
    @pulumi.getter(name="instanceNumber")
    def instance_number(self) -> pulumi.Output[builtins.int]:
        """
        执行实例数量。
        """
        return pulumi.get(self, "instance_number")

    @property
    @pulumi.getter(name="invocationDescription")
    def invocation_description(self) -> pulumi.Output[builtins.str]:
        """
        作业描述，默认为空字符串，不超过256个字符。
        """
        return pulumi.get(self, "invocation_description")

    @property
    @pulumi.getter(name="invocationId")
    def invocation_id(self) -> pulumi.Output[builtins.str]:
        """
        任务执行 ID。
        """
        return pulumi.get(self, "invocation_id")

    @property
    @pulumi.getter(name="invocationName")
    def invocation_name(self) -> pulumi.Output[builtins.str]:
        """
        作业名称。不超过64个字符。暂不限制特殊字符。同地域下作业名称可重复。
        """
        return pulumi.get(self, "invocation_name")

    @property
    @pulumi.getter(name="invocationResults")
    def invocation_results(self) -> pulumi.Output[Sequence['outputs.InvocationInvocationResult']]:
        return pulumi.get(self, "invocation_results")

    @property
    @pulumi.getter(name="invocationStatus")
    def invocation_status(self) -> pulumi.Output[builtins.str]:
        """
        命令执行的总执行状态。
        """
        return pulumi.get(self, "invocation_status")

    @property
    @pulumi.getter(name="launchTime")
    def launch_time(self) -> pulumi.Output[builtins.str]:
        """
        执行时间。
        """
        return pulumi.get(self, "launch_time")

    @property
    @pulumi.getter(name="parameterDefinitions")
    def parameter_definitions(self) -> pulumi.Output[Sequence['outputs.InvocationParameterDefinition']]:
        return pulumi.get(self, "parameter_definitions")

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[builtins.str]:
        """
        命令中包含自定义参数时，需通过本参数传入自定义参数的键值对。自定义参数个数范围为0~60。Key不允许为空字符串，最多支持64个字符。Value允许为空字符串。自定义参数与原始命令内容在Base64编码后，综合长度不能超过16KB。设置的自定义参数名集合必须为创建命令时定义的参数集的子集。对于未传入的参数，使用默认值代替。
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        资源所属项目，一个资源只能归属于一个项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="recurrenceEndTime")
    def recurrence_end_time(self) -> pulumi.Output[builtins.str]:
        """
        周期结束时间，仅适用于周期任务（Rate）。
        """
        return pulumi.get(self, "recurrence_end_time")

    @property
    @pulumi.getter(name="repeatMode")
    def repeat_mode(self) -> pulumi.Output[builtins.str]:
        """
        设置命令执行的方式。Once：默认，表示立即执行命令。Rate：周期执行命令，需要通过Frequency参数传入Rate表达式指定执行周期。Fixed：定时执行命令，需要通过LaunchTime参数指定的执行时间。
        """
        return pulumi.get(self, "repeat_mode")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Output[builtins.str]:
        """
        任务开始时间。
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.InvocationTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[builtins.int]:
        """
        创建的命令在ECS实例中执行时最大的超时时间，单位为秒。默认值：60。可选范围为：30~86400。
        """
        return pulumi.get(self, "timeout")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[builtins.str]:
        """
        在ECS实例中执行命令的用户名称。
        """
        return pulumi.get(self, "username")

    @property
    @pulumi.getter(name="windowsPassword")
    def windows_password(self) -> pulumi.Output[builtins.str]:
        """
        自定义windows用户的密码。
        """
        return pulumi.get(self, "windows_password")

    @property
    @pulumi.getter(name="workingDir")
    def working_dir(self) -> pulumi.Output[builtins.str]:
        """
        创建的命令在ECS实例中运行的目录。
        """
        return pulumi.get(self, "working_dir")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNetworkAclResult',
    'AwaitableGetNetworkAclResult',
    'get_network_acl',
    'get_network_acl_output',
]

@pulumi.output_type
class GetNetworkAclResult:
    """
    A collection of values returned by getNetworkAcl.
    """
    def __init__(__self__, created_time=None, default_egress_acl_entries=None, default_ingress_acl_entries=None, description=None, egress_acl_entries=None, id=None, ingress_acl_entries=None, network_acl_id=None, network_acl_name=None, project_name=None, resources=None, status=None, tags=None, updated_time=None, vpc_id=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if default_egress_acl_entries and not isinstance(default_egress_acl_entries, list):
            raise TypeError("Expected argument 'default_egress_acl_entries' to be a list")
        pulumi.set(__self__, "default_egress_acl_entries", default_egress_acl_entries)
        if default_ingress_acl_entries and not isinstance(default_ingress_acl_entries, list):
            raise TypeError("Expected argument 'default_ingress_acl_entries' to be a list")
        pulumi.set(__self__, "default_ingress_acl_entries", default_ingress_acl_entries)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if egress_acl_entries and not isinstance(egress_acl_entries, list):
            raise TypeError("Expected argument 'egress_acl_entries' to be a list")
        pulumi.set(__self__, "egress_acl_entries", egress_acl_entries)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ingress_acl_entries and not isinstance(ingress_acl_entries, list):
            raise TypeError("Expected argument 'ingress_acl_entries' to be a list")
        pulumi.set(__self__, "ingress_acl_entries", ingress_acl_entries)
        if network_acl_id and not isinstance(network_acl_id, str):
            raise TypeError("Expected argument 'network_acl_id' to be a str")
        pulumi.set(__self__, "network_acl_id", network_acl_id)
        if network_acl_name and not isinstance(network_acl_name, str):
            raise TypeError("Expected argument 'network_acl_name' to be a str")
        pulumi.set(__self__, "network_acl_name", network_acl_name)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if resources and not isinstance(resources, list):
            raise TypeError("Expected argument 'resources' to be a list")
        pulumi.set(__self__, "resources", resources)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        网络ACL的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="defaultEgressAclEntries")
    def default_egress_acl_entries(self) -> Sequence['outputs.GetNetworkAclDefaultEgressAclEntryResult']:
        """
        默认出向ACL规则列表。
        """
        return pulumi.get(self, "default_egress_acl_entries")

    @property
    @pulumi.getter(name="defaultIngressAclEntries")
    def default_ingress_acl_entries(self) -> Sequence['outputs.GetNetworkAclDefaultIngressAclEntryResult']:
        """
        默认入向ACL规则列表。
        """
        return pulumi.get(self, "default_ingress_acl_entries")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        网络ACL描述信息。长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="egressAclEntries")
    def egress_acl_entries(self) -> Sequence['outputs.GetNetworkAclEgressAclEntryResult']:
        """
        出向ACL规则列表。
        """
        return pulumi.get(self, "egress_acl_entries")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ingressAclEntries")
    def ingress_acl_entries(self) -> Sequence['outputs.GetNetworkAclIngressAclEntryResult']:
        """
        入向ACL规则列表。
        """
        return pulumi.get(self, "ingress_acl_entries")

    @property
    @pulumi.getter(name="networkAclId")
    def network_acl_id(self) -> builtins.str:
        """
        网络ACL的ID。
        """
        return pulumi.get(self, "network_acl_id")

    @property
    @pulumi.getter(name="networkAclName")
    def network_acl_name(self) -> builtins.str:
        """
        网络ACL名称。长度限制为1 ~ 128个字符。需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "network_acl_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        网络ACL所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def resources(self) -> Sequence['outputs.GetNetworkAclResourceResult']:
        """
        关联资源列表。
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        网络ACL的状态。Available：可用，Creating：创建中
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetNetworkAclTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        网络ACL的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        网络ACL所属VPC的ID。
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetNetworkAclResult(GetNetworkAclResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkAclResult(
            created_time=self.created_time,
            default_egress_acl_entries=self.default_egress_acl_entries,
            default_ingress_acl_entries=self.default_ingress_acl_entries,
            description=self.description,
            egress_acl_entries=self.egress_acl_entries,
            id=self.id,
            ingress_acl_entries=self.ingress_acl_entries,
            network_acl_id=self.network_acl_id,
            network_acl_name=self.network_acl_name,
            project_name=self.project_name,
            resources=self.resources,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time,
            vpc_id=self.vpc_id)


def get_network_acl(id: Optional[builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkAclResult:
    """
    Data Source schema for Byteplus::VPC::NetworkAcl


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getNetworkAcl:getNetworkAcl', __args__, opts=opts, typ=GetNetworkAclResult).value

    return AwaitableGetNetworkAclResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        default_egress_acl_entries=pulumi.get(__ret__, 'default_egress_acl_entries'),
        default_ingress_acl_entries=pulumi.get(__ret__, 'default_ingress_acl_entries'),
        description=pulumi.get(__ret__, 'description'),
        egress_acl_entries=pulumi.get(__ret__, 'egress_acl_entries'),
        id=pulumi.get(__ret__, 'id'),
        ingress_acl_entries=pulumi.get(__ret__, 'ingress_acl_entries'),
        network_acl_id=pulumi.get(__ret__, 'network_acl_id'),
        network_acl_name=pulumi.get(__ret__, 'network_acl_name'),
        project_name=pulumi.get(__ret__, 'project_name'),
        resources=pulumi.get(__ret__, 'resources'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_network_acl_output(id: Optional[pulumi.Input[builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkAclResult]:
    """
    Data Source schema for Byteplus::VPC::NetworkAcl


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getNetworkAcl:getNetworkAcl', __args__, opts=opts, typ=GetNetworkAclResult)
    return __ret__.apply(lambda __response__: GetNetworkAclResult(
        created_time=pulumi.get(__response__, 'created_time'),
        default_egress_acl_entries=pulumi.get(__response__, 'default_egress_acl_entries'),
        default_ingress_acl_entries=pulumi.get(__response__, 'default_ingress_acl_entries'),
        description=pulumi.get(__response__, 'description'),
        egress_acl_entries=pulumi.get(__response__, 'egress_acl_entries'),
        id=pulumi.get(__response__, 'id'),
        ingress_acl_entries=pulumi.get(__response__, 'ingress_acl_entries'),
        network_acl_id=pulumi.get(__response__, 'network_acl_id'),
        network_acl_name=pulumi.get(__response__, 'network_acl_name'),
        project_name=pulumi.get(__response__, 'project_name'),
        resources=pulumi.get(__response__, 'resources'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServerGroupArgs', 'ServerGroup']

@pulumi.input_type
class ServerGroupArgs:
    def __init__(__self__, *,
                 load_balancer_id: pulumi.Input[builtins.str],
                 address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 any_port_enabled: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ServerGroup resource.
        :param pulumi.Input[builtins.str] load_balancer_id: 后端服务器组所属的CLB实例ID。
        :param pulumi.Input[builtins.str] address_ip_version: 后端服务器组的IP地址类型。ipv4：后端服务器组为IPv4类型。ipv6：后端服务器组为IPv6类型。
        :param pulumi.Input[builtins.str] any_port_enabled: 是否开启全端口转发。on：开启全端口转发。off：关闭全端口转发。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个符。不填则默认为空字符串。
        :param pulumi.Input[builtins.str] server_group_name: 后端服务器组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。不填默认为后端服务器组ID。
        :param pulumi.Input[builtins.str] type: 后端服务器组的类型。instance：表示该后端服务器组只能添加云服务器的主网卡或辅助网卡作为后端服务器。ip：表示该后端服务器组只能添加IP地址作为后端服务器。
        """
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if address_ip_version is not None:
            pulumi.set(__self__, "address_ip_version", address_ip_version)
        if any_port_enabled is not None:
            pulumi.set(__self__, "any_port_enabled", any_port_enabled)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if server_group_name is not None:
            pulumi.set(__self__, "server_group_name", server_group_name)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Input[builtins.str]:
        """
        后端服务器组所属的CLB实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的IP地址类型。ipv4：后端服务器组为IPv4类型。ipv6：后端服务器组为IPv6类型。
        """
        return pulumi.get(self, "address_ip_version")

    @address_ip_version.setter
    def address_ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address_ip_version", value)

    @property
    @pulumi.getter(name="anyPortEnabled")
    def any_port_enabled(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启全端口转发。on：开启全端口转发。off：关闭全端口转发。
        """
        return pulumi.get(self, "any_port_enabled")

    @any_port_enabled.setter
    def any_port_enabled(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "any_port_enabled", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个符。不填则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。不填默认为后端服务器组ID。
        """
        return pulumi.get(self, "server_group_name")

    @server_group_name.setter
    def server_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_name", value)

    @property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]:
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]):
        pulumi.set(self, "servers", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的类型。instance：表示该后端服务器组只能添加云服务器的主网卡或辅助网卡作为后端服务器。ip：表示该后端服务器组只能添加IP地址作为后端服务器。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _ServerGroupState:
    def __init__(__self__, *,
                 address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 any_port_enabled: Optional[pulumi.Input[builtins.str]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 listeners: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupListenerArgs']]]] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServerGroup resources.
        :param pulumi.Input[builtins.str] address_ip_version: 后端服务器组的IP地址类型。ipv4：后端服务器组为IPv4类型。ipv6：后端服务器组为IPv6类型。
        :param pulumi.Input[builtins.str] any_port_enabled: 是否开启全端口转发。on：开启全端口转发。off：关闭全端口转发。
        :param pulumi.Input[builtins.str] create_time: 后端服务器组的创建时间。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个符。不填则默认为空字符串。
        :param pulumi.Input[builtins.str] load_balancer_id: 后端服务器组所属的CLB实例ID。
        :param pulumi.Input[builtins.str] server_group_id: 后端服务器组的ID。
        :param pulumi.Input[builtins.str] server_group_name: 后端服务器组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。不填默认为后端服务器组ID。
        :param pulumi.Input[builtins.str] type: 后端服务器组的类型。instance：表示该后端服务器组只能添加云服务器的主网卡或辅助网卡作为后端服务器。ip：表示该后端服务器组只能添加IP地址作为后端服务器。
        :param pulumi.Input[builtins.str] update_time: 后端服务器组的最近操作时间。
        """
        if address_ip_version is not None:
            pulumi.set(__self__, "address_ip_version", address_ip_version)
        if any_port_enabled is not None:
            pulumi.set(__self__, "any_port_enabled", any_port_enabled)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if listeners is not None:
            pulumi.set(__self__, "listeners", listeners)
        if load_balancer_id is not None:
            pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if server_group_id is not None:
            pulumi.set(__self__, "server_group_id", server_group_id)
        if server_group_name is not None:
            pulumi.set(__self__, "server_group_name", server_group_name)
        if servers is not None:
            pulumi.set(__self__, "servers", servers)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的IP地址类型。ipv4：后端服务器组为IPv4类型。ipv6：后端服务器组为IPv6类型。
        """
        return pulumi.get(self, "address_ip_version")

    @address_ip_version.setter
    def address_ip_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address_ip_version", value)

    @property
    @pulumi.getter(name="anyPortEnabled")
    def any_port_enabled(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否开启全端口转发。on：开启全端口转发。off：关闭全端口转发。
        """
        return pulumi.get(self, "any_port_enabled")

    @any_port_enabled.setter
    def any_port_enabled(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "any_port_enabled", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的创建时间。
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个符。不填则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def listeners(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupListenerArgs']]]]:
        return pulumi.get(self, "listeners")

    @listeners.setter
    def listeners(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupListenerArgs']]]]):
        pulumi.set(self, "listeners", value)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组所属的CLB实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @server_group_id.setter
    def server_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_id", value)

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。不填默认为后端服务器组ID。
        """
        return pulumi.get(self, "server_group_name")

    @server_group_name.setter
    def server_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_name", value)

    @property
    @pulumi.getter
    def servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]:
        return pulumi.get(self, "servers")

    @servers.setter
    def servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupServerArgs']]]]):
        pulumi.set(self, "servers", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerGroupTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的类型。instance：表示该后端服务器组只能添加云服务器的主网卡或辅助网卡作为后端服务器。ip：表示该后端服务器组只能添加IP地址作为后端服务器。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        后端服务器组的最近操作时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)


@pulumi.type_token("bytepluscc:clb/serverGroup:ServerGroup")
class ServerGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 any_port_enabled: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupTagArgs', 'ServerGroupTagArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        后端服务器组是一组后端服务器。

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/serverGroup:ServerGroup example "server_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] address_ip_version: 后端服务器组的IP地址类型。ipv4：后端服务器组为IPv4类型。ipv6：后端服务器组为IPv6类型。
        :param pulumi.Input[builtins.str] any_port_enabled: 是否开启全端口转发。on：开启全端口转发。off：关闭全端口转发。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个符。不填则默认为空字符串。
        :param pulumi.Input[builtins.str] load_balancer_id: 后端服务器组所属的CLB实例ID。
        :param pulumi.Input[builtins.str] server_group_name: 后端服务器组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。不填默认为后端服务器组ID。
        :param pulumi.Input[builtins.str] type: 后端服务器组的类型。instance：表示该后端服务器组只能添加云服务器的主网卡或辅助网卡作为后端服务器。ip：表示该后端服务器组只能添加IP地址作为后端服务器。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServerGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        后端服务器组是一组后端服务器。

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/serverGroup:ServerGroup example "server_group_id"
        ```

        :param str resource_name: The name of the resource.
        :param ServerGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
                 any_port_enabled: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupTagArgs', 'ServerGroupTagArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerGroupArgs.__new__(ServerGroupArgs)

            __props__.__dict__["address_ip_version"] = address_ip_version
            __props__.__dict__["any_port_enabled"] = any_port_enabled
            __props__.__dict__["description"] = description
            if load_balancer_id is None and not opts.urn:
                raise TypeError("Missing required property 'load_balancer_id'")
            __props__.__dict__["load_balancer_id"] = load_balancer_id
            __props__.__dict__["server_group_name"] = server_group_name
            __props__.__dict__["servers"] = servers
            __props__.__dict__["tags"] = tags
            __props__.__dict__["type"] = type
            __props__.__dict__["create_time"] = None
            __props__.__dict__["listeners"] = None
            __props__.__dict__["server_group_id"] = None
            __props__.__dict__["update_time"] = None
        super(ServerGroup, __self__).__init__(
            'bytepluscc:clb/serverGroup:ServerGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address_ip_version: Optional[pulumi.Input[builtins.str]] = None,
            any_port_enabled: Optional[pulumi.Input[builtins.str]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            listeners: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupListenerArgs', 'ServerGroupListenerArgsDict']]]]] = None,
            load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
            server_group_id: Optional[pulumi.Input[builtins.str]] = None,
            server_group_name: Optional[pulumi.Input[builtins.str]] = None,
            servers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupServerArgs', 'ServerGroupServerArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerGroupTagArgs', 'ServerGroupTagArgsDict']]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            update_time: Optional[pulumi.Input[builtins.str]] = None) -> 'ServerGroup':
        """
        Get an existing ServerGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] address_ip_version: 后端服务器组的IP地址类型。ipv4：后端服务器组为IPv4类型。ipv6：后端服务器组为IPv6类型。
        :param pulumi.Input[builtins.str] any_port_enabled: 是否开启全端口转发。on：开启全端口转发。off：关闭全端口转发。
        :param pulumi.Input[builtins.str] create_time: 后端服务器组的创建时间。
        :param pulumi.Input[builtins.str] description: 后端服务器组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个符。不填则默认为空字符串。
        :param pulumi.Input[builtins.str] load_balancer_id: 后端服务器组所属的CLB实例ID。
        :param pulumi.Input[builtins.str] server_group_id: 后端服务器组的ID。
        :param pulumi.Input[builtins.str] server_group_name: 后端服务器组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。不填默认为后端服务器组ID。
        :param pulumi.Input[builtins.str] type: 后端服务器组的类型。instance：表示该后端服务器组只能添加云服务器的主网卡或辅助网卡作为后端服务器。ip：表示该后端服务器组只能添加IP地址作为后端服务器。
        :param pulumi.Input[builtins.str] update_time: 后端服务器组的最近操作时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerGroupState.__new__(_ServerGroupState)

        __props__.__dict__["address_ip_version"] = address_ip_version
        __props__.__dict__["any_port_enabled"] = any_port_enabled
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["listeners"] = listeners
        __props__.__dict__["load_balancer_id"] = load_balancer_id
        __props__.__dict__["server_group_id"] = server_group_id
        __props__.__dict__["server_group_name"] = server_group_name
        __props__.__dict__["servers"] = servers
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["update_time"] = update_time
        return ServerGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的IP地址类型。ipv4：后端服务器组为IPv4类型。ipv6：后端服务器组为IPv6类型。
        """
        return pulumi.get(self, "address_ip_version")

    @property
    @pulumi.getter(name="anyPortEnabled")
    def any_port_enabled(self) -> pulumi.Output[builtins.str]:
        """
        是否开启全端口转发。on：开启全端口转发。off：关闭全端口转发。
        """
        return pulumi.get(self, "any_port_enabled")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个符。不填则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def listeners(self) -> pulumi.Output[Sequence['outputs.ServerGroupListener']]:
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组所属的CLB实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。不填默认为后端服务器组ID。
        """
        return pulumi.get(self, "server_group_name")

    @property
    @pulumi.getter
    def servers(self) -> pulumi.Output[Sequence['outputs.ServerGroupServer']]:
        return pulumi.get(self, "servers")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.ServerGroupTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的类型。instance：表示该后端服务器组只能添加云服务器的主网卡或辅助网卡作为后端服务器。ip：表示该后端服务器组只能添加IP地址作为后端服务器。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[builtins.str]:
        """
        后端服务器组的最近操作时间。
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetNameSpaceResult',
    'AwaitableGetNameSpaceResult',
    'get_name_space',
    'get_name_space_output',
]

@pulumi.output_type
class GetNameSpaceResult:
    """
    A collection of values returned by getNameSpace.
    """
    def __init__(__self__, created_time=None, id=None, name=None, project=None, registry=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if registry and not isinstance(registry, str):
            raise TypeError("Expected argument 'registry' to be a str")
        pulumi.set(__self__, "registry", registry)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        命名空间的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        命名空间名称。支持小写英文、数字、英文句号（.）、短划线（-）、下划线（_），标点符号不能出现在首位或末位，也不能连续输入。长度限制为 2～90 个字符。标准版实例：同一个镜像仓库实例下，名称必须唯一。体验版实例：同一地域下，所有账号范围内的命名空间名称需要保持唯一。如果您设置的命名空间名称已被占用，请尝试其他名称或者 购买标准版实例。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> builtins.str:
        """
        命名空间所属项目的名称。参数值大小写敏感，不得超过 64 个字符。参数为空时，命名空间关联默认的 default项目。
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def registry(self) -> builtins.str:
        """
        指定的镜像仓库实例名称。通过 ListRegistries 或在 镜像仓库控制台 的 实例列表页面获取。
        """
        return pulumi.get(self, "registry")


class AwaitableGetNameSpaceResult(GetNameSpaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNameSpaceResult(
            created_time=self.created_time,
            id=self.id,
            name=self.name,
            project=self.project,
            registry=self.registry)


def get_name_space(id: Optional[builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNameSpaceResult:
    """
    Data Source schema for Byteplus::CR::NameSpace


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:cr/getNameSpace:getNameSpace', __args__, opts=opts, typ=GetNameSpaceResult).value

    return AwaitableGetNameSpaceResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        project=pulumi.get(__ret__, 'project'),
        registry=pulumi.get(__ret__, 'registry'))
def get_name_space_output(id: Optional[pulumi.Input[builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNameSpaceResult]:
    """
    Data Source schema for Byteplus::CR::NameSpace


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:cr/getNameSpace:getNameSpace', __args__, opts=opts, typ=GetNameSpaceResult)
    return __ret__.apply(lambda __response__: GetNameSpaceResult(
        created_time=pulumi.get(__response__, 'created_time'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        project=pulumi.get(__response__, 'project'),
        registry=pulumi.get(__response__, 'registry')))
